@@ -184,7 +184,8 @@ class Page(pyscp.core.Page):
     def source(self):
         data = self._module('viewsource/ViewSourceModule')['body']
         soup = bs4.BeautifulSoup(data, 'lxml')
-        return ''.join([s + '\n' for s in soup.text.replace('\t','').split('\n')[1:]][1:])
+        source = ''.join([s + '\n' for s in soup.text.replace('\t','').split('\n')[1:]][1:])
+        return 
 
     @property
     def created(self):
